@@ -812,11 +812,11 @@ class CKANWrapper:
             responseStruct = resp.json()
             retValStr = json.dumps(responseStruct)
             LOGGER.debug(f"Package Updated: {retValStr[0:125]} ...")
-            if resp.status_code < 200 or resp.status_code >= 300:
-                if "Only lists of dicts can be placed against subschema ('more_info'" in responseStruct['message']:
-                    raise MoreInfoNeedsDeStringify(retValStr)
-                else:
-                    raise InvalidRequestError(retValStr)
+
+            if (resp.status_code == 409) and "Only lists of dicts can be placed against subschema ('more_info'" in responseStruct['message']:
+                raise MoreInfoNeedsDeStringify(retValStr)
+            elif resp.status_code < 200 or resp.status_code >= 300:
+                raise InvalidRequestError(retValStr)
         except requests.exceptions.ReadTimeout:
             if retry:
                 LOGGER.error("have already tried resending this request")
